==> apache-ambari-2.6.2-src.tar.gz: apache-ambari-2.6.2-src/ambari-server/src/test/java/org/apache/ambari/server/audit/TaskStatusAuditEventTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ambari.server.audit;

import org.apache.ambari.server.actionmanager.HostRoleStatus;
import org.apache.ambari.server.audit.event.TaskStatusAuditEvent;
import org.junit.Test;

import static org.hamcrest.core.IsEqual.equalTo;
import static org.junit.Assert.assertThat;

public class TaskStatusAuditEventTest {

  @Test
  public void testAuditMessage() throws Exception {
    // Given
    String testUserName = "USER1";
    String testOperation = "START MYCOMPONENT";
    String testRequestDetails = "Start MyComponent";
    String testHostName = "ambari.example.com";
    HostRoleStatus testStatus = HostRoleStatus.IN_PROGRESS;
    Long testRequestId = 100L;
    Long testTaskId = 99L;

    TaskStatusAuditEvent event = TaskStatusAuditEvent.builder()
      .withTimestamp(System.currentTimeMillis())
      .withUserName(testUserName)
      .withOperation(testOperation)
      .withRequestId(testRequestId.toString())
      .withDetails(testRequestDetails)
      .withHostName(testHostName)
      .withStatus(testStatus.name())
      .withTaskId(testTaskId.toString())
      .build();

    // When
    String actualAuditMessage = event.getAuditMessage();

    // Then
    String expectedAuditMessage = String.format("User(%s), Operation(%s), Details(%s), Status(%s), RequestId(%d), TaskId(%d), Hostname(%s)", testUserName, testOperation, testRequestDetails, testStatus, testRequestId, testTaskId, testHostName);

    assertThat(actualAuditMessage, equalTo(expectedAuditMessage));

  }

}

==> apache-ambari-2.7.9-src.tar.gz: apache-ambari-2.7.9-src/ambari-server/src/test/java/org/apache/ambari/server/audit/TaskStatusAuditEventTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ambari.server.audit;

import static org.hamcrest.core.IsEqual.equalTo;
import static org.junit.Assert.assertThat;

import org.apache.ambari.server.actionmanager.HostRoleStatus;
import org.apache.ambari.server.audit.event.TaskStatusAuditEvent;
import org.junit.Test;

public class TaskStatusAuditEventTest {

  @Test
  public void testAuditMessage() throws Exception {
    // Given
    String testUserName = "USER1";

    String testRemoteIp = "127.0.0.1";
    String testOperation = "START MYCOMPONENT";
    String testRequestDetails = "Start MyComponent";
    String testHostName = "ambari.example.com";
    HostRoleStatus testStatus = HostRoleStatus.IN_PROGRESS;
    Long testRequestId = 100L;
    Long testTaskId = 99L;

    TaskStatusAuditEvent event = TaskStatusAuditEvent.builder()
      .withTimestamp(System.currentTimeMillis())
      .withUserName(testUserName)
      .withRemoteIp(testRemoteIp)
      .withOperation(testOperation)
      .withRequestId(testRequestId.toString())
      .withDetails(testRequestDetails)
      .withHostName(testHostName)
      .withStatus(testStatus.name())
      .withTaskId(testTaskId.toString())
      .build();

    // When
    String actualAuditMessage = event.getAuditMessage();

    // Then
    String expectedAuditMessage = String.format("User(%s), RemoteIp(%s), Operation(%s), Details(%s), Status(%s), RequestId(%d), TaskId(%d), Hostname(%s)", testUserName, testRemoteIp, testOperation, testRequestDetails, testStatus, testRequestId, testTaskId, testHostName);

    assertThat(actualAuditMessage, equalTo(expectedAuditMessage));

  }

}
